==> KleckFiles(5.80.00).zip: KleckFiles/wiki/page/notebook/m_startrekOrig.js <==
var wikiMetaData = {created:'230829', modified:'230829'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Star Trek - The Original Series</h1>",
"<p class='_w_glossary'>In the ((Original)) Series, Captain Kirk (name means 'church'), ",
"prattles on with high-minded-moral earth bound ideas; While Spock a hybrid (half Vulcan (god of fire) / half human) voices his logic while everyone ridicules him for not being human enough; ",
"And a crew of real men, and women in unbelievably short mini skirts, Trek between the ((stars)) ",
"in fake space. It's biblical. It's a mockery of us, as they know earth is a closed system where they covertly farm and murder ((stars)).",
"As with all TV shows, terror is masked with humor, Kirk is charming, killing and death is normal, Jesus the King of Kings is never mentioned, and episodes all resolve and have mostly happy endings (unlike this earth).",
"</p>",
	
"<p class='pageTOC' id='pageTOC'></p>",
	
"<h2 class='pageTOC'>Pilot - The Cage</h2>",
"<p>Held in captivity by a superior underground race, our hero is manipulated through illusion, lies and mind-control. ",
"They create the illusion of a beautiful woman to control him. She is actually repulsive in reality.",
"</p>",
"<p>The starship captain escapes, happy ending presented.",
"</p>",

"<h2 class='pageTOC'>S1:E1 - The Man Trap</h2>",
"<p>Stardate 1513.1, Planet M-113. A rotine medical examination of archaeologist Dr Crater and wife Nancy.",
"Nancy is a shape shifter posing as a human woman. A very deadly illusion. Each man see what he wants to see. ",
"Nancy kills by leaching all salt from a person. It's her nature to do so. Good at blending in, using charm to seduce and lying.",
"</p>",
"<p class='_w_bibleVerse'>Matt 5:13|Ye are the salt of the earth: but if the salt have lost his savour, wherewith shall it be salted? it is thenceforth good for nothing, but to be cast out, and to be trodden under foot of men.",	
"</p>",

"<h2 class='pageTOC'>S1:E2 - Charlie X</h2>",
"<p>Stardate 1533.6, Charlie X is found living alone on a planet and is given passage on the Enterprise. ",
"He lacks social norms and has never seen a woman. Selfish and obsessive, so Kirk takes him under his wing.",
"But Charlie has powers, and can transmute objects (their words). He is now a danger, killing and takes over the ship.",
"</p>",
"<p>Eventually his powerful transdimensional alien keeper arrives, damage control and and takes Charlie away. Charlie throws one last tantrum.",
"</p>",
"<p class='_w_glossary'>Charlies means 'a free man', 'X' is female energy. The moral?? The only thing that comes to mind is that this is training video for serpents. If you don't blend in and hide the ((magic)) you will be delt with by a higher authority.",
"</p>",
	
"<h2 class='pageTOC'>S1:E3 - Where no man has gone before</h2>",
"<p>A man and women of the crew come in contact with a space anomaly and receive god like powers.",
"Things turn nasty as our new gods want to rule, destroy, control others.",
"</p>",
"<p>This plot is ridiculous.",
"Jesus explains, to be the greatest in the Kingdom of heaven is to serve. Our Father is all powerful and is always doing good for all, whether people deserve it or not.",
"Jesus said 'have I not said ye are Elohim, but will die like men'.",
"Lucifer wanted to rise above the stars of El. So the episode dumbs down bible truth and attributes of our Father and Jesus. TV programming a false reality as usual. Meanwhile as evident by wars and Maui, this world is controlled by the god of forces (the force be with you, is all they know).",
"</p>",
"<p class='_w_bibleVerse'>Mat 11:12|And from the days of John the Baptist until now the kingdom of heaven suffereth violence, and the violent take it by force.</p>",

""
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/notebook/m_startrekOrig.js <==
var wikiMetaData = {created:'230829', modified:'230829'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Star Trek - The Original Series</h1>",
"<p class='_w_glossary'>In the ((Original)) Series, Captain Kirk (name means 'church'), ",
"prattles on with high-minded-moral earth bound ideas; While Spock a hybrid (half Vulcan (god of fire) / half human) voices his logic while everyone ridicules him for not being human enough; ",
"And a crew of real men, and women in unbelievably short mini skirts, Trek between the ((stars)) ",
"in fake space. It's biblical. It's a mockery of us, as they know earth is a closed system where they covertly farm and murder ((stars)).",
"As with all TV shows, terror is masked with humor, Kirk is charming, killing and death is normal, Jesus the King of Kings is never mentioned, and episodes all resolve and have mostly happy endings (unlike this earth).",
"</p>",
	
"<p class='pageTOC' id='pageTOC'></p>",
	
"<h2 class='pageTOC'>Pilot - The Cage</h2>",
"<p>Held in captivity by a superior underground race, our hero is manipulated through illusion, lies and mind-control. ",
"They create the illusion of a beautiful woman to control him. She is actually repulsive in reality.",
"</p>",
"<p>The starship captain escapes, happy ending presented.",
"</p>",

"<h2 class='pageTOC'>S1:E1 - The Man Trap</h2>",
"<p>Stardate 1513.1, Planet M-113. A routine medical examination of archaeologist Dr Crater and wife Nancy.",
"Nancy is a shape shifter posing as a human woman. A very deadly illusion. Each man see what he wants to see. ",
"Nancy kills by leaching all salt from a person. It's her nature to do so. Good at blending in, using charm to seduce and lying.",
"</p>",
"<p class='_w_bibleVerse'>Matt 5:13|Ye are the salt of the earth: but if the salt have lost his savour, wherewith shall it be salted? it is thenceforth good for nothing, but to be cast out, and to be trodden under foot of men.",	
"</p>",

"<h2 class='pageTOC'>S1:E2 - Charlie X</h2>",
"<p>Stardate 1533.6, Charlie X is found living alone on a planet and is given passage on the Enterprise. ",
"He lacks social norms and has never seen a woman. Selfish and obsessive, so Kirk takes him under his wing.",
"But Charlie has powers, and can transmute objects (their words). He is now a danger, killing and takes over the ship.",
"</p>",
"<p>Eventually his powerful transdimensional alien keeper arrives, damage control and and takes Charlie away. Charlie throws one last tantrum.",
"</p>",
"<p class='_w_glossary'>Charlies means 'a free man', 'X' is female energy. The moral?? The only thing that comes to mind is that this is training video for serpents. If you don't blend in and hide the ((magic)) you will be delt with by a higher authority.",
"</p>",
	
"<h2 class='pageTOC'>S1:E3 - Where no man has gone before</h2>",
"<p>A man and women of the crew come in contact with a space anomaly and receive god like powers.",
"Things turn nasty as our new gods want to rule, destroy, control others.",
"</p>",
"<p>This plot is ridiculous.",
"Jesus explains, to be the greatest in the Kingdom of heaven is to serve. Our Father is all powerful and is always doing good for all, whether people deserve it or not.",
"Jesus said 'have I not said ye are Elohim, but will die like men'.",
"Lucifer wanted to rise above the stars of El. So the episode dumbs down bible truth and attributes of our Father and Jesus. TV programming a false reality as usual. Meanwhile as evident by wars and Maui, this world is controlled by the god of forces (the force be with you, is all they know).",
"</p>",
"<p class='_w_bibleVerse'>Mat 11:12|And from the days of John the Baptist until now the kingdom of heaven suffereth violence, and the violent take it by force.</p>",

""
];
